# Equation Solver

`equation-solver` es una librería de Python que permite resolver sistemas de ecuaciones lineales y no lineales mediante distintos métodos numéricos.

## Métodos disponibles

### Ecuaciones lineales:
- Eliminación de Gauss
- Gauss-Jordan
- Regla de Cramer
- Descomposición LU
- Método de Jacobi
- Método de Gauss-Seidel

### Ecuaciones no lineales:
- Método de Bisección

## Instalación
```bash
pip numpy
pip install --upgrade setuptools pip wheel
pip install HP23005UNO
